use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007005
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib ) );
__DATA__
Ahmad
Alders
Alders'
Alexandr
Anwar
Book
Bowers
Ciornii
Custodio
Dan
Download
Estrade
Flavio
Isyaltut
Kucharski
Maurice
Mikolaj
Mohammad
Neil
Olaf
Paulo
Poletti
Roy
Shimada
Sibley
Storey
Syaltut
TANIGUCHI
Takaki
Thomas
WWW
Wada
YouTube
Yuji
Yusuke
Zucker
akiyama
akiym
alexchorny
cpan
estrabd
flavio
flv
gregoa
gregor
grinnz
herrmann
isync
kiwiroy
ks
lib
mauricemengel
mikolaj
mohammad
neil
olaf
pauloscustodio
playlist
script
takaki
tsibley
webm
webpage
widthxheight
xaicron
youtube
yusuke
yusukebe
